HS300

Struct HS300 

pub struct HS300<T: Protocol> { /* private fields */ }
A HS300 smart power strip with energy monitoring

When directly creating a device using the from_* methods below, you must make sure that the address you pass is indeed that of a HS300, as there is no further checking.

Implementations

Source

impl HS300<DefaultProtocol>

pub fn new(addr: &str) -> Result<Self, AddrParseError>

Make a HS300 device from an address string

pub fn from_addr(addr: SocketAddr) -> Self

Make a HS300 device from an address struct

Source

impl<T: Protocol> HS300<T>

pub fn from_raw(raw: RawDevice<T>) -> Self

Make a HS300 device from an already constructed raw device