pub struct HS300<T: Protocol> { /* private fields */ }Expand description
A HS300 smart power strip with energy monitoring
When directly creating a device using the from_* methods below, you must make sure that the address you pass is indeed that of a HS300, as there is no further checking.
Implementations